==> keyclic_sdk_api-1.28.9.tar.gz: lib/model/feedback_links.dart <==
part of keyclic_sdk_api.api;

class FeedbackLinks {
  FeedbackLinksSelf self = null;

  FeedbackLinksCategory category = null;

  FeedbackLinksBusinessActivity businessActivity = null;

  FeedbackLinksReporter reporter = null;

  FeedbackLinksImage image = null;

  FeedbackLinksTracking tracking = null;

  FeedbackLinks();

  @override
  String toString() {
    return 'FeedbackLinks[self=$self, category=$category, businessActivity=$businessActivity, reporter=$reporter, image=$image, tracking=$tracking, ]';
  }

  FeedbackLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    self = new FeedbackLinksSelf.fromJson(json['self']);
    category = new FeedbackLinksCategory.fromJson(json['category']);
    businessActivity =
        new FeedbackLinksBusinessActivity.fromJson(json['businessActivity']);
    reporter = new FeedbackLinksReporter.fromJson(json['reporter']);
    image = new FeedbackLinksImage.fromJson(json['image']);
    tracking = new FeedbackLinksTracking.fromJson(json['tracking']);
  }

  Map<String, dynamic> toJson() {
    return {
      'self': self,
      'category': category,
      'businessActivity': businessActivity,
      'reporter': reporter,
      'image': image,
      'tracking': tracking
    };
  }

  static List<FeedbackLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<FeedbackLinks>()
        : json.map((value) => new FeedbackLinks.fromJson(value)).toList();
  }

  static Map<String, FeedbackLinks> mapFromJson(Map<String, dynamic> json) {
    var map = new Map<String, FeedbackLinks>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new FeedbackLinks.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.31.2.tar.gz: lib/model/feedback_links.dart <==
part of keyclic_sdk_api.api;

class FeedbackLinks {
  FeedbackLinksSelf self = null;

  FeedbackLinksCategory category = null;

  FeedbackLinksBusinessActivity businessActivity = null;

  FeedbackLinksReporter reporter = null;

  FeedbackLinksImage image = null;

  FeedbackLinksTracking tracking = null;

  List<FeedbackLinksImages> images = [];

  FeedbackLinks();

  @override
  String toString() {
    return 'FeedbackLinks[self=$self, category=$category, businessActivity=$businessActivity, reporter=$reporter, image=$image, tracking=$tracking, images=$images, ]';
  }

  FeedbackLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    self = new FeedbackLinksSelf.fromJson(json['self']);
    category = new FeedbackLinksCategory.fromJson(json['category']);
    businessActivity =
        new FeedbackLinksBusinessActivity.fromJson(json['businessActivity']);
    reporter = new FeedbackLinksReporter.fromJson(json['reporter']);
    image = new FeedbackLinksImage.fromJson(json['image']);
    tracking = new FeedbackLinksTracking.fromJson(json['tracking']);
    images = FeedbackLinksImages.listFromJson(json['images']);
  }

  Map<String, dynamic> toJson() {
    return {
      'self': self,
      'category': category,
      'businessActivity': businessActivity,
      'reporter': reporter,
      'image': image,
      'tracking': tracking,
      'images': images
    };
  }

  static List<FeedbackLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<FeedbackLinks>()
        : json.map((value) => new FeedbackLinks.fromJson(value)).toList();
  }

  static Map<String, FeedbackLinks> mapFromJson(Map<String, dynamic> json) {
    var map = new Map<String, FeedbackLinks>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new FeedbackLinks.fromJson(value));
    }
    return map;
  }
}
